R class to represent H-polytopes.A H-polytope is a convex polytope defined by a set of linear inequalities or equivalently a \(d\)-dimensional H-polytope with \(m\) facets is defined by a \(m\times d\) matrix A and a \(m\)-dimensional vector b, s.t.: \(P=\{x\ |\ Ax\leq b\} \).
A A \(m\times d\) numerical matrix A
b \(m\)-dimensional vector b
type An integer that declares the representation of the polytope. For H-representation the default value is 1.
dimension The dimension of the polytope.
volume The volume of the polytope, if it is known.